==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ServiceAccountListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ServiceAccountListFluent<A extends V1ServiceAccountListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1ServiceAccount item);
    public A setToItems(int index,V1ServiceAccount item);
    public A addToItems(V1ServiceAccount... items);
    public A addAllToItems(Collection<V1ServiceAccount> items);
    public A removeFromItems(V1ServiceAccount... items);
    public A removeAllFromItems(Collection<V1ServiceAccount> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ServiceAccount> getItems();
    public List<V1ServiceAccount> buildItems();
    public V1ServiceAccount buildItem(int index);
    public V1ServiceAccount buildFirstItem();
    public V1ServiceAccount buildLastItem();
    public V1ServiceAccount buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ServiceAccountBuilder> predicate);
    public A withItems(List<V1ServiceAccount> items);
    public A withItems(V1ServiceAccount... items);
    public Boolean hasItems();
    public V1ServiceAccountListFluent.ItemsNested<A> addNewItem();
    public V1ServiceAccountListFluent.ItemsNested<A> addNewItemLike(V1ServiceAccount item);
    public V1ServiceAccountListFluent.ItemsNested<A> setNewItemLike(int index,V1ServiceAccount item);
    public V1ServiceAccountListFluent.ItemsNested<A> editItem(int index);
    public V1ServiceAccountListFluent.ItemsNested<A> editFirstItem();
    public V1ServiceAccountListFluent.ItemsNested<A> editLastItem();
    public V1ServiceAccountListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ServiceAccountBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> withNewMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ServiceAccountListFluent.MetadataNested<A> editMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ServiceAccountFluent<V1ServiceAccountListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ServiceAccountListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ServiceAccountListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ServiceAccountListFluent<A extends V1ServiceAccountListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1ServiceAccount item);
    public A setToItems(int index,V1ServiceAccount item);
    public A addToItems(V1ServiceAccount... items);
    public A addAllToItems(Collection<V1ServiceAccount> items);
    public A removeFromItems(V1ServiceAccount... items);
    public A removeAllFromItems(Collection<V1ServiceAccount> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ServiceAccount> getItems();
    public List<V1ServiceAccount> buildItems();
    public V1ServiceAccount buildItem(int index);
    public V1ServiceAccount buildFirstItem();
    public V1ServiceAccount buildLastItem();
    public V1ServiceAccount buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ServiceAccountBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1ServiceAccountBuilder> predicate);
    public A withItems(List<V1ServiceAccount> items);
    public A withItems(V1ServiceAccount... items);
    public Boolean hasItems();
    public V1ServiceAccountListFluent.ItemsNested<A> addNewItem();
    public V1ServiceAccountListFluent.ItemsNested<A> addNewItemLike(V1ServiceAccount item);
    public V1ServiceAccountListFluent.ItemsNested<A> setNewItemLike(int index,V1ServiceAccount item);
    public V1ServiceAccountListFluent.ItemsNested<A> editItem(int index);
    public V1ServiceAccountListFluent.ItemsNested<A> editFirstItem();
    public V1ServiceAccountListFluent.ItemsNested<A> editLastItem();
    public V1ServiceAccountListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ServiceAccountBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> withNewMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ServiceAccountListFluent.MetadataNested<A> editMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ServiceAccountListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ServiceAccountFluent<V1ServiceAccountListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ServiceAccountListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
